@@ -14,10 +14,12 @@
 #  limitations under the License.
 ##
 
-labkey.selectRows <- function(baseUrl, folderPath, schemaName, queryName, viewName=NULL, colSelect=NULL,
+labkey.selectRows <- function(baseUrl=NULL, folderPath, schemaName, queryName, viewName=NULL, colSelect=NULL,
         maxRows=NULL, rowOffset=NULL, colSort=NULL, colFilter=NULL, showHidden=FALSE, colNameOpt='caption',
         containerFilter=NULL, parameters=NULL, includeDisplayValues=FALSE)
 {
+baseUrl=labkey.getBaseUrl(baseUrl)    
+  
 ## Empty string/NULL checking
 if(is.null(viewName)==FALSE) {char <- nchar(viewName); if(char<1){viewName<-NULL}}
 if(is.null(colSelect)==FALSE) {char <- nchar(colSelect[1]); if(char<1){colSelect<-NULL}}
@@ -31,8 +33,8 @@ if(is.null(parameters)==FALSE) {char <- nchar(parameters[1]); if(char<1){paramet
 if(is.null(includeDisplayValues)==FALSE) {char <- nchar(includeDisplayValues); if(char<1){includeDisplayValues<-FALSE}}
 
 ## Error if any of baseUrl, folderPath, schemName or queryName are missing
-if(exists("baseUrl")==FALSE || exists("folderPath")==FALSE || exists("schemaName")==FALSE || exists("queryName")==FALSE)
-stop (paste("A value must be specified for each of baseUrl, folderPath, schemaName and queryName."))
+if(exists("baseUrl")==FALSE || is.null(baseUrl) ||exists("folderPath")==FALSE || exists("schemaName")==FALSE || exists("queryName")==FALSE)
+    stop (paste("A value must be specified for each of baseUrl, folderPath, schemaName and queryName."))
 
 ## URL encoding of schema, query, view, etc. (if not already encoded)
 if(schemaName==curlUnescape(schemaName)) {schemaName <- curlEscape(schemaName)}
