@@ -103,6 +103,12 @@
 								"NO_MV_INDICATOR"="nomvvalue",
 								"NOT_QC_VALUE"="nomvvalue",
 
+								#
+								# Table/Query-wise operators
+								#
+
+								"Q"="q"
+
 								)
 
  				if(is.null(fop)==TRUE) stop ("Invalid operator name.")
